Index: trunk/MagicSoft/Mars/Changelog
===================================================================
--- trunk/MagicSoft/Mars/Changelog	(revision 4317)
+++ trunk/MagicSoft/Mars/Changelog	(revision 4318)
@@ -24,4 +24,8 @@
     - use flag to choose if one wants to re-normalize the histogram 
       results
+
+  * mhist/MHCamera.[h,cc]
+    - added one argument to CntCamContent to tell if event above or 
+      below threshold have to be counted. Default is above, like before
 
 
Index: trunk/MagicSoft/Mars/mhist/MHCamera.h
===================================================================
--- trunk/MagicSoft/Mars/mhist/MHCamera.h	(revision 4317)
+++ trunk/MagicSoft/Mars/mhist/MHCamera.h	(revision 4318)
@@ -150,5 +150,5 @@
     virtual void     SetUsed(const TArrayC &arr);
 
-    virtual void     CntCamContent(const MCamEvent &evt, Double_t threshold, Int_t type=0);
+    virtual void     CntCamContent(const MCamEvent &evt, Double_t threshold, Int_t type=0, Bool_t isabove=kTRUE);
     virtual void     CntCamContent(const TArrayD &evt, Double_t threshold, Bool_t ispos=kTRUE);
 

Index: trunk/MagicSoft/Mars/mhist/MHCamera.cc
===================================================================
--- trunk/MagicSoft/Mars/mhist/MHCamera.cc	(revision 4317)
+++ trunk/MagicSoft/Mars/mhist/MHCamera.cc	(revision 4318)
@@ -1212,7 +1212,8 @@
 //
 // Call this function to add a MCamEvent on top of the present contents.
-// 1 is added to each pixel if the contents of MCamEvent>threshold
-//
-void MHCamera::CntCamContent(const MCamEvent &event, Double_t threshold, Int_t type)
+// 1 is added to each pixel if the contents of MCamEvent>threshold (in case isabove is set to kTRUE == default)
+// 1 is added to each pixel if the contents of MCamEvent<threshold (in case isabove is set to kFALSE)
+//
+void MHCamera::CntCamContent(const MCamEvent &event, Double_t threshold, Int_t type, Bool_t isabove)
 {
     if (fNcells<=1 || IsFreezed())
@@ -1226,5 +1227,7 @@
             SetUsed(idx);
 
-        if (val>threshold)
+        if (val>threshold && isabove)
+            Fill(idx);
+        if (val<threshold && !isabove)
             Fill(idx);
     }